@@ -52,7 +52,7 @@ void Active_KillSession(Packet*, EncodeFlags*);
 
 void Active_SendReset(Packet*, EncodeFlags);
 void Active_SendUnreach(Packet*, EncodeType);
-void Active_SendData(Packet*, EncodeFlags, const uint8_t* buf, uint32_t len);
+bool Active_SendData(Packet*, EncodeFlags, const uint8_t* buf, uint32_t len);
 void Active_InjectData(Packet*, EncodeFlags, const uint8_t* buf, uint32_t len);
 
 int Active_IsRSTCandidate(const Packet*);
@@ -71,8 +71,14 @@ typedef enum {
     ACTIVE_FORCE_DROP   // must drop
 } tActiveDrop;
 
+typedef enum {
+    ACTIVE_SSN_ALLOW,       // don't drop
+    ACTIVE_SSN_DROP,        // can drop and reset
+    ACTIVE_SSN_DROP_WITHOUT_RESET,  // can drop but without reset
+} tActiveSsnDrop;
+
 extern tActiveDrop active_drop_pkt;
-extern int active_drop_ssn;
+extern tActiveSsnDrop active_drop_ssn;
 #ifdef ACTIVE_RESPONSE
 extern int active_have_rsp;
 #endif
@@ -82,7 +88,7 @@ extern int active_suspend;
 static inline void Active_Reset (void)
 {
     active_drop_pkt = ACTIVE_ALLOW;
-    active_drop_ssn = 0;
+    active_drop_ssn = ACTIVE_SSN_ALLOW;
 #ifdef ACTIVE_RESPONSE
     active_have_rsp = 0;
 #endif
@@ -104,7 +110,7 @@ static inline bool Active_Suspended (void)
     return ( active_suspend != 0 );
 }
 
-static tActiveDrop Active_GetDisposition (void)
+static inline tActiveDrop Active_GetDisposition (void)
 {
     return active_drop_pkt;
 }
@@ -130,6 +136,28 @@ static inline void Active_ForceDropPacket (void)
         active_drop_pkt = ACTIVE_FORCE_DROP;
 }
 
+static inline void Active_NapDropPacket (const Packet* p)
+{
+    if ( Active_Suspended() )
+    {
+        Active_CantDrop();
+    }
+    else if ( active_drop_pkt != ACTIVE_FORCE_DROP )
+    {
+        if ( ScNapInlineMode() )
+        {
+            if ( DAQ_GetInterfaceMode(p->pkth) == DAQ_MODE_INLINE )
+                active_drop_pkt = ACTIVE_DROP;
+            else
+                active_drop_pkt = ACTIVE_WOULD_DROP;
+        }
+        else if (ScNapInlineTestMode())
+        {
+            active_drop_pkt = ACTIVE_WOULD_DROP;
+        }
+    }
+}
+
 static inline void Active_DropPacket (const Packet* p)
 {
     if ( Active_Suspended() )
@@ -138,40 +166,75 @@ static inline void Active_DropPacket (const Packet* p)
     }
     else if ( active_drop_pkt != ACTIVE_FORCE_DROP )
     {
-        if ( ScInlineMode() )
+        if ( ScIpsInlineMode() )
         {
             if ( DAQ_GetInterfaceMode(p->pkth) == DAQ_MODE_INLINE )
                 active_drop_pkt = ACTIVE_DROP;
             else
                 active_drop_pkt = ACTIVE_WOULD_DROP;
         }
-        else if (ScInlineTestMode())
+        else if (ScIpsInlineTestMode())
         {
             active_drop_pkt = ACTIVE_WOULD_DROP;
         }
     }
 }
 
-static inline void Active_DropSession (const Packet* p)
+static inline void Active_DAQDropPacket(const Packet *p)
+{
+    if ( Active_Suspended() )
+    {
+        Active_CantDrop();
+    }
+    else if ( active_drop_pkt != ACTIVE_FORCE_DROP )
+    {
+        if ( DAQ_GetInterfaceMode(p->pkth) == DAQ_MODE_INLINE )
+            active_drop_pkt = ACTIVE_DROP;
+        else
+            active_drop_pkt = ACTIVE_WOULD_DROP;
+    }
+}
+
+static inline void _Active_DropSession (const Packet* p, tActiveSsnDrop ssn_drop)
 {
     if ( Active_Suspended() )
     {
         Active_CantDrop();
         return;
     }
-    active_drop_ssn = 1;
+    active_drop_ssn = ssn_drop;
     Active_DropPacket(p);
 }
 
+static inline void _Active_ForceDropSession (tActiveSsnDrop ssn_drop)
+{
+    if ( Active_Suspended() )
+    {
+        Active_CantDrop();
+        return;
+    }
+    active_drop_ssn = ssn_drop;
+    Active_ForceDropPacket();
+}
+
+static inline void Active_DropSession (const Packet* p)
+{
+    _Active_DropSession(p, ACTIVE_SSN_DROP);
+}
+
 static inline void Active_ForceDropSession (void)
 {
-    if ( Active_Suspended() )
-    {
-        Active_CantDrop();
-        return;
-    }
-    active_drop_ssn = 1;
-    Active_ForceDropPacket();
+    _Active_ForceDropSession(ACTIVE_SSN_DROP);
+}
+
+static inline void Active_DropSessionWithoutReset (const Packet* p)
+{
+    _Active_DropSession(p, ACTIVE_SSN_DROP_WITHOUT_RESET);
+}
+
+static inline void Active_ForceDropSessionWithoutReset (void)
+{
+    _Active_ForceDropSession(ACTIVE_SSN_DROP_WITHOUT_RESET);
 }
 
 static inline int Active_PacketWouldBeDropped (void)
@@ -191,13 +254,13 @@ static inline int Active_PacketWasDropped (void)
 
 static inline int Active_SessionWasDropped (void)
 {
-    return ( active_drop_ssn != 0 );
+    return ( active_drop_ssn != ACTIVE_SSN_ALLOW );
 }
 
 #ifdef ACTIVE_RESPONSE
 static inline int Active_ResponseQueued (void)
 {
-    return ( active_have_rsp != 0 );
+    return ( active_have_rsp != ACTIVE_SSN_ALLOW );
 }
 #endif
 
