@@ -47,7 +47,7 @@
 
 #define VLAN_HDR_LEN  4
 
-// for vrt backwards compatibility
+/* for vrt backwards compatibility */
 #define pcap_header pkt_header
 
 typedef int (*LogFunction)(void *ssnptr, uint8_t **buf, uint32_t *len, uint32_t *type);
@@ -65,7 +65,7 @@ typedef struct _VlanHeader
 
 } VlanHeader;
 
-//#define NO_NON_ETHER_DECODER
+/*#define NO_NON_ETHER_DECODER */
 #define ETHER_HDR_LEN  14
 #define ETHERNET_TYPE_IP    0x0800
 #define ETHERNET_TYPE_IPV6  0x86dd
@@ -117,7 +117,7 @@ typedef struct _IPV4Header
 
 #define MAX_LOG_FUNC   32
 #define MAX_IP_OPTIONS 40
-#define MAX_IP6_EXTENSIONS 8
+
 /* ip option codes */
 #define IPOPTION_EOL            0x00
 #define IPOPTION_NOP            0x01
@@ -337,10 +337,10 @@ typedef struct _IPv4Hdr
 
 typedef struct _IP6RawHdr
 {
-    uint32_t vcl;          // version, class, and label */
-    uint16_t payload_len;  // length of the payload */
-    uint8_t  next_header;  // same values as ip4 protocol field + new ip6 values
-    uint8_t  hop_limit;    // same usage as ip4 ttl
+    uint32_t vcl;          /* version, class, and label */
+    uint16_t payload_len;  /* length of the payload */
+    uint8_t  next_header;  /* same values as ip4 protocol field + new ip6 values */
+    uint8_t  hop_limit;    /* same usage as ip4 ttl */
 
     struct in6_addr src_addr;
     struct in6_addr dst_addr;
@@ -463,6 +463,9 @@ typedef struct {
     uint8_t* proto_start;
 } ProtoLayer;
 
+// for backwards compatibility with VRT .so rules
+#define stream_session_ptr stream_session
+
 typedef struct _SFSnortPacket
 {
     const SFDAQ_PktHdr_t *pkt_header; /* Is this GPF'd? */
@@ -490,7 +493,7 @@ typedef struct _SFSnortPacket
     const uint8_t *ip_payload;
     const uint8_t *outer_ip_payload;
 
-    void *stream_session_ptr;
+    void *stream_session;
     void *fragmentation_tracking_ptr;
 
     IP4Hdr *ip4h, *orig_ip4h;
@@ -578,7 +581,7 @@ typedef struct _SFSnortPacket
 
     IPOptions ip_options[MAX_IP_OPTIONS];
     TCPOptions tcp_options[MAX_TCP_OPTIONS];
-    IP6Extension ip6_extensions[MAX_IP6_EXTENSIONS];
+    IP6Extension *ip6_extensions;
 
     const uint8_t *ip_frag_start;
     const uint8_t *ip4_options_data;
@@ -605,8 +608,10 @@ typedef struct _SFSnortPacket
     uint32_t iplist_id;
     unsigned char iprep_layer;
 
-    uint8_t ps_proto;  // Used for portscan and unified2 logging
+    uint8_t ps_proto;  /* Used for portscan and unified2 logging */
 
+    uint8_t ips_os_selected; 
+    void    *cur_pp;
 } SFSnortPacket;
 
 #define IP_INNER_LAYER   1
@@ -641,7 +646,7 @@ typedef struct _SFSnortPacket
 #define BIT(i) (0x1 << (i-1))
 
 
-// beware:  some flags are redefined in dynamic-plugins/sf_dynamic_define.h!
+/* beware:  some flags are redefined in dynamic-plugins/sf_dynamic_define.h! */
 #define FLAG_REBUILT_FRAG     0x00000001  /* is a rebuilt fragment */
 #define FLAG_REBUILT_STREAM   0x00000002  /* is a rebuilt stream */
 #define FLAG_STREAM_UNEST_UNI 0x00000004  /* is from an unestablished stream and
@@ -679,9 +684,9 @@ typedef struct _SFSnortPacket
 #define FLAG_RESIZED          0x00800000  /* packet has new size; must set modified too */
 #endif
 
-// neither of these flags will be set for (full) retransmissions or non-data segments
-// a partial overlap results in out of sequence condition
-// out of sequence condition is sticky
+/* neither of these flags will be set for (full) retransmissions or non-data segments */
+/* a partial overlap results in out of sequence condition */
+/* out of sequence condition is sticky */
 #define FLAG_STREAM_ORDER_OK  0x01000000  /* this segment is in order, w/o gaps */
 #define FLAG_STREAM_ORDER_BAD 0x02000000  /* this stream had at least one gap */
 #define FLAG_REASSEMBLED_OLD  0x04000000  /* for backwards compat with so rules */
@@ -689,7 +694,7 @@ typedef struct _SFSnortPacket
 #define FLAG_IPREP_SOURCE_TRIGGERED  0x08000000
 #define FLAG_IPREP_DATA_SET          0x10000000
 #define FLAG_FILE_EVENT_SET          0x20000000
-// 0x40000000 are available
+/* 0x40000000 are available */
 
 #define FLAG_PDU_FULL (FLAG_PDU_HEAD | FLAG_PDU_TAIL)
 
