@@ -262,7 +262,7 @@ void DCE2_ClProcess(DCE2_SsnData *sd, DCE2_ClTracker *clt)
 
             case DCERPC_PDU_TYPE__RESPONSE:
                 DEBUG_WRAP(DCE2_DebugMsg(DCE2_DEBUG__CL, "Response from client.  Changing stream direction."));
-                _dpd.streamAPI->update_direction(sd->wire_pkt->stream_session_ptr, SSN_DIR_FROM_RESPONDER,
+                _dpd.streamAPI->update_direction(sd->wire_pkt->stream_session, SSN_DIR_FROM_RESPONDER,
                                                  GET_SRC_IP(((SFSnortPacket *)sd->wire_pkt)),
                                                  sd->wire_pkt->src_port);
                 break;
