@@ -24,7 +24,7 @@
  *
  * imap_log.c
  *
- * Author: Bhagyashree Bantwal <bbantwal@sourcefire.com>
+ * Author: Bhagyashree Bantwal <bbantwal@cisco.com>
  *
  * Description:
  *
@@ -88,20 +88,21 @@ void IMAP_GenerateAlert(int event, char *format, ...)
     va_end(ap);
 }
 
-void IMAP_DecodeAlert(void)
+void IMAP_DecodeAlert(void *ds)
 {
-    switch( imap_ssn->decode_state->decode_type )
+    Email_DecodeState *decode_state = (Email_DecodeState *)ds;
+    switch( decode_state->decode_type )
     {
     case DECODE_B64:
-        if (imap_eval_config->b64_depth > -1)
+        if (imap_eval_config->decode_conf.b64_depth > -1)
             IMAP_GenerateAlert(IMAP_B64_DECODING_FAILED, "%s", IMAP_B64_DECODING_FAILED_STR);
         break;
     case DECODE_QP:
-        if (imap_eval_config->qp_depth > -1)
+        if (imap_eval_config->decode_conf.qp_depth > -1)
             IMAP_GenerateAlert(IMAP_QP_DECODING_FAILED, "%s", IMAP_QP_DECODING_FAILED_STR);
         break;
     case DECODE_UU:
-        if (imap_eval_config->uu_depth > -1)
+        if (imap_eval_config->decode_conf.uu_depth > -1)
             IMAP_GenerateAlert(IMAP_UU_DECODING_FAILED, "%s", IMAP_UU_DECODING_FAILED_STR);
         break;
 
