@@ -31,6 +31,7 @@
 #include "spp_modbus.h"
 #include "modbus_decode.h"
 #include "modbus_roptions.h"
+#include "modbus_paf.h"
 
 /* Mapping of name -> function code for 'modbus_func' option. */
 static modbus_func_map_t func_map[] =
@@ -207,11 +208,11 @@ int ModbusRuleEval(void *raw_packet, const uint8_t **cursor, void *data)
     /* The preprocessor only evaluates PAF-flushed PDUs. If the rule options
        don't check for this, they'll fire on stale session data when the
        original packet goes through before flushing. */
-    if (!PacketHasFullPDU(packet))
+    if (!PacketHasFullPDU(packet) && ModbusIsPafActive(packet))
         return RULE_NOMATCH;
 
     session_data = (modbus_session_data_t *)
-        _dpd.streamAPI->get_application_data(packet->stream_session_ptr, PP_MODBUS);
+        _dpd.sessionAPI->get_application_data(packet->stream_session, PP_MODBUS);
 
     if ((packet->payload_size == 0 ) || (session_data == NULL))
     {
