@@ -54,11 +54,6 @@
 #include "sfPolicy.h"
 
 
-/*  Global variable to hold configuration */
-extern SMTPConfig **smtp_config;
-
-extern const SMTPToken smtp_known_cmds[];
-
 /* Private functions */
 static int  ProcessPorts(SMTPConfig *, char *, int);
 static int ProcessCmds(SMTPConfig *, char *, int, int, SMTPCmdTypeEnum);
@@ -68,7 +63,6 @@ static int  ProcessAltMaxCmdLen(SMTPConfig *, char *, int);
 static int  ProcessMaxMimeDepth(SMTPConfig *, char *, int);
 static int  ProcessLogDepth(SMTPConfig *, char *, int);
 static int  ProcessXlink2State(SMTPConfig *, char *, int);
-static int ProcessDecodeDepth(SMTPConfig *, char *, int , char *, DecodeType );
 
 /*
  * Function: SMTP_ParseArgs(char *)
@@ -90,34 +84,25 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
     char *value;
     char errStr[ERRSTRLEN];
     int errStrLen = ERRSTRLEN;
-    int b64_option = 0;
     int deprecated_options = 0;
 
     if ((config == NULL) || (args == NULL))
         return;
 
-    config->ports[SMTP_DEFAULT_SERVER_PORT / 8]     |= 1 << (SMTP_DEFAULT_SERVER_PORT % 8);
-    config->ports[XLINK2STATE_DEFAULT_PORT / 8]     |= 1 << (XLINK2STATE_DEFAULT_PORT % 8);
-    config->ports[SMTP_DEFAULT_SUBMISSION_PORT / 8] |= 1 << (SMTP_DEFAULT_SUBMISSION_PORT % 8);
+    enablePort( config->ports, SMTP_DEFAULT_SERVER_PORT );
+    enablePort( config->ports, XLINK2STATE_DEFAULT_PORT );
+    enablePort( config->ports, SMTP_DEFAULT_SUBMISSION_PORT );
     config->inspection_type = SMTP_STATELESS;
     config->max_command_line_len = DEFAULT_MAX_COMMAND_LINE_LEN;
     config->max_header_line_len = DEFAULT_MAX_HEADER_LINE_LEN;
     config->max_response_line_len = DEFAULT_MAX_RESPONSE_LINE_LEN;
     config->max_mime_depth = DEFAULT_MAX_MIME_DEPTH;
-    config->max_mime_mem = DEFAULT_MAX_MIME_MEM;
     config->memcap = DEFAULT_SMTP_MEMCAP;
     config->alert_xlink2state = 1;
     config->print_cmds = 1;
     config->enable_mime_decoding = 0;
-    config->b64_depth = DEFAULT_MAX_MIME_DEPTH;
-    config->qp_depth = DEFAULT_MAX_MIME_DEPTH;
-    config->uu_depth = DEFAULT_MAX_MIME_DEPTH;
-    config->bitenc_depth = DEFAULT_MAX_MIME_DEPTH;
-    config->max_depth = MIN_DEPTH;
-    config->log_config.log_filename = 0;
-    config->log_config.log_mailfrom = 0;
-    config->log_config.log_rcptto = 0;
-    config->log_config.log_email_hdrs = 0;
+    _dpd.fileAPI->set_mime_decode_config_defauts(&(config->decode_conf));
+    _dpd.fileAPI->set_mime_log_config_defauts(&(config->log_config));
     config->log_config.email_hdrs_log_depth = DEFAULT_LOG_DEPTH;
 
     config->cmd_config = (SMTPCmdConfig *)calloc(CMD_LAST, sizeof(SMTPCmdConfig));
@@ -178,7 +163,7 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
         }
         else if ( !strcasecmp(CONF_IGNORE_DATA, arg) )
         {
-            config->ignore_data = 1;
+            config->decode_conf.ignore_data = 1;
         }
         else if ( !strcasecmp(CONF_IGNORE_TLS_DATA, arg) )
         {
@@ -264,23 +249,21 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
         {
             ret = _dpd.checkValueInRange(strtok(NULL, CONF_SEPARATORS), CONF_MAX_MIME_MEM,
                     MIN_MIME_MEM, MAX_MIME_MEM, &val);
-            config->max_mime_mem = (int)val;
+            config->decode_conf.max_mime_mem = (int)val;
         }
         else if ( !strcasecmp(CONF_MAX_MIME_DEPTH, arg) )
         {
             deprecated_options = 1;
             _dpd.logMsg("WARNING: %s(%d) => The SMTP config option 'max_mime_depth' is deprecated.\n",
                             *(_dpd.config_file), *(_dpd.config_line));
-            if(!b64_option)
-                ret = ProcessMaxMimeDepth(config, errStr, errStrLen);
+            ret = ProcessMaxMimeDepth(config, errStr, errStrLen);
         }
         else if ( !strcasecmp(CONF_ENABLE_MIME_DECODING, arg) )
         {
             deprecated_options = 1;
             _dpd.logMsg("WARNING: %s(%d) => The SMTP config option 'enable_mime_decoding' is deprecated.\n",
                                         *(_dpd.config_file), *(_dpd.config_line));
-            if(!b64_option)
-                config->enable_mime_decoding = 1;
+            config->enable_mime_decoding = 1;
         }
         else if ( !strcasecmp(CONF_DISABLED, arg) )
         {
@@ -315,22 +298,10 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
         {
             config->print_cmds = 1;
         }
-        else if ( !strcasecmp(CONF_B64_DECODE, arg) )
+
+        else if(!_dpd.fileAPI->parse_mime_decode_args(&(config->decode_conf), arg, "SMTP"))
         {
-            b64_option = 1;
-            ret = ProcessDecodeDepth(config, errStr, errStrLen, CONF_B64_DECODE, DECODE_B64);
-        }
-        else if ( !strcasecmp(CONF_QP_DECODE, arg) )
-        {
-            ret = ProcessDecodeDepth(config, errStr, errStrLen, CONF_QP_DECODE, DECODE_QP);
-        }
-        else if ( !strcasecmp(CONF_UU_DECODE, arg) )
-        {
-            ret = ProcessDecodeDepth(config, errStr, errStrLen, CONF_UU_DECODE, DECODE_UU);
-        }
-        else if ( !strcasecmp(CONF_BITENC_DECODE, arg) )
-        {
-            ret = ProcessDecodeDepth(config, errStr, errStrLen, CONF_BITENC_DECODE, DECODE_BITENC);
+            ret = 0;
         }
         else
         {
@@ -359,10 +330,12 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
         arg = strtok(NULL, CONF_SEPARATORS);
     }
 
-    if(!b64_option)
+    // NOTE: the default b64_depth is not defined in this file 
+    //       but is equal to DEFAULT_MAX_MIME_DEPTH
+    if(config->decode_conf.b64_depth == DEFAULT_MAX_MIME_DEPTH)
     {
         if(config->enable_mime_decoding)
-            config->b64_depth = config->max_mime_depth;
+            config->decode_conf.b64_depth = config->max_mime_depth;
     }
     else if(deprecated_options)
     {
@@ -383,54 +356,17 @@ void SMTP_ParseArgs(SMTPConfig *config, char *args)
     }
 
 }
-int SMTP_IsDecodingEnabled(SMTPConfig *pPolicyConfig)
-{
-    if( (pPolicyConfig->b64_depth > -1) || (pPolicyConfig->qp_depth > -1)
-         || (pPolicyConfig->uu_depth > -1) || (pPolicyConfig->bitenc_depth > -1)
-         ||(pPolicyConfig->file_depth > -1))
-    {
-        return 0;
-    }
-    else
-        return -1;
-
-}
-
 
 void SMTP_CheckConfig(SMTPConfig *pPolicyConfig, tSfPolicyUserContextId context)
 {
-    int max = -1;
     SMTPConfig *defaultConfig =
                 (SMTPConfig *)sfPolicyUserDataGetDefault(context);
 
     if (pPolicyConfig == defaultConfig)
     {
-        if (!pPolicyConfig->max_mime_mem)
-            pPolicyConfig->max_mime_mem = DEFAULT_MAX_MIME_MEM;
-
-        if(!pPolicyConfig->b64_depth || !pPolicyConfig->qp_depth
-                || !pPolicyConfig->uu_depth || !pPolicyConfig->bitenc_depth)
-        {
-            pPolicyConfig->max_depth = MAX_DEPTH;
+        if (!_dpd.fileAPI->check_decoding_conf(&(pPolicyConfig->decode_conf),
+                &(defaultConfig->decode_conf), "SMTP"))
             return;
-        }
-        else
-        {
-            if(max < pPolicyConfig->b64_depth)
-                max = pPolicyConfig->b64_depth;
-
-            if(max < pPolicyConfig->qp_depth)
-                max = pPolicyConfig->qp_depth;
-
-            if(max < pPolicyConfig->bitenc_depth)
-                max = pPolicyConfig->bitenc_depth;
-
-            if(max < pPolicyConfig->uu_depth)
-                max = pPolicyConfig->uu_depth;
-
-            pPolicyConfig->max_depth = max;
-        }
-
 
         if (!pPolicyConfig->memcap)
             pPolicyConfig->memcap = DEFAULT_SMTP_MEMCAP;
@@ -441,40 +377,8 @@ void SMTP_CheckConfig(SMTPConfig *pPolicyConfig, tSfPolicyUserContextId context)
     }
     else if (defaultConfig == NULL)
     {
-        if (pPolicyConfig->max_mime_mem)
-        {
-            DynamicPreprocessorFatalMessage("%s(%d) => SMTP: max_mime_mem must be "
-                   "configured in the default config.\n",
-                    *(_dpd.config_file), *(_dpd.config_line));
-        }
-
-        if (pPolicyConfig->b64_depth > -1)
-        {
-            DynamicPreprocessorFatalMessage("%s(%d) => SMTP: b64_decode_depth must be "
-                   "configured in the default config.\n",
-                  *(_dpd.config_file), *(_dpd.config_line));
-        }
-
-        if (pPolicyConfig->qp_depth > -1)
-        {
-            DynamicPreprocessorFatalMessage("%s(%d) => SMTP: qp_decode_depth must be "
-                       "configured in the default config.\n",
-                      *(_dpd.config_file), *(_dpd.config_line));
-        }
-
-        if (pPolicyConfig->uu_depth > -1)
-        {
-            DynamicPreprocessorFatalMessage("%s(%d) => SMTP: uu_decode_depth must be "
-                       "configured in the default config.\n",
-                      *(_dpd.config_file), *(_dpd.config_line));
-        }
-
-        if (pPolicyConfig->bitenc_depth > -1)
-        {
-            DynamicPreprocessorFatalMessage("%s(%d) => SMTP: bitenc_decode_depth must be "
-                       "configured in the default config.\n",
-                      *(_dpd.config_file), *(_dpd.config_line));
-        }
+        _dpd.fileAPI->check_decoding_conf(&(pPolicyConfig->decode_conf),
+                        NULL, "SMTP");
 
         if (pPolicyConfig->memcap)
         {
@@ -493,73 +397,15 @@ void SMTP_CheckConfig(SMTPConfig *pPolicyConfig, tSfPolicyUserContextId context)
     }
     else
     {
-        pPolicyConfig->max_mime_mem = defaultConfig->max_mime_mem;
-        pPolicyConfig->max_depth = defaultConfig->max_depth;
         pPolicyConfig->memcap = defaultConfig->memcap;
         pPolicyConfig->log_config.email_hdrs_log_depth = defaultConfig->log_config.email_hdrs_log_depth;
         if(pPolicyConfig->disabled)
         {
-            pPolicyConfig->b64_depth = defaultConfig->b64_depth;
-            pPolicyConfig->qp_depth = defaultConfig->qp_depth;
-            pPolicyConfig->uu_depth = defaultConfig->uu_depth;
-            pPolicyConfig->bitenc_depth = defaultConfig->bitenc_depth;
-            return;
-        }
-        if(!pPolicyConfig->b64_depth && defaultConfig->b64_depth)
-        {
-            DynamicPreprocessorFatalMessage("%s(%d) => SMTP: Cannot enable unlimited Base64 decoding"
-                                    " in non-default config without turning on unlimited Base64 decoding in the default "
-                                    " config.\n",
-                                    *(_dpd.config_file), *(_dpd.config_line));
-        }
-        else if(defaultConfig->b64_depth && (pPolicyConfig->b64_depth > defaultConfig->b64_depth))
-        {
-            DynamicPreprocessorFatalMessage("%s(%d) => SMTP: b64_decode_depth value %d in non-default config"
-                                       " cannot exceed default config's value %d.\n",
-                                       *(_dpd.config_file), *(_dpd.config_line), pPolicyConfig->b64_depth, defaultConfig->b64_depth);
-        }
-
-        if(!pPolicyConfig->qp_depth && defaultConfig->qp_depth)
-        {
-            DynamicPreprocessorFatalMessage("%s(%d) => SMTP: Cannot enable unlimited Quoted-Printable decoding"
-                                        " in non-default config without turning on unlimited Quoted-Printable decoding in the default "
-                                        " config.\n",
-                                        *(_dpd.config_file), *(_dpd.config_line));
-        }
-        else if(defaultConfig->qp_depth && (pPolicyConfig->qp_depth > defaultConfig->qp_depth))
-        {
-            DynamicPreprocessorFatalMessage("%s(%d) => SMTP: qp_decode_depth value %d in non-default config"
-                                           " cannot exceed default config's value %d.\n",
-                                           *(_dpd.config_file), *(_dpd.config_line), pPolicyConfig->qp_depth, defaultConfig->qp_depth);
-        }
-
-        if(!pPolicyConfig->uu_depth && defaultConfig->uu_depth )
-        {
-            DynamicPreprocessorFatalMessage("%s(%d) => SMTP: Cannot enable unlimited Unix-to-Unix decoding"
-                                " in non-default config without turning on unlimited Unix-to-Unix decoding in the default "
-                                " config.\n",
-                                *(_dpd.config_file), *(_dpd.config_line));
-        }
-        else if(defaultConfig->uu_depth && (pPolicyConfig->uu_depth > defaultConfig->uu_depth))
-        {
-            DynamicPreprocessorFatalMessage("%s(%d) => SMTP: uu_decode_depth value %d in non-default config"
-                                   " cannot exceed default config's value %d.\n",
-                                   *(_dpd.config_file), *(_dpd.config_line), pPolicyConfig->uu_depth, defaultConfig->uu_depth);
-        }
-
-        if(!pPolicyConfig->bitenc_depth && defaultConfig->bitenc_depth)
-        {
-            DynamicPreprocessorFatalMessage("%s(%d) => SMTP: Cannot enable unlimited Non-Encoded MIME attachment extraction"
-                                        " in non-default config without turning on unlimited Non-Encoded MIME attachment extraction in the default "
-                                        " config.\n",
-                                        *(_dpd.config_file), *(_dpd.config_line));
-        }
-        else if(defaultConfig->bitenc_depth && (pPolicyConfig->bitenc_depth > defaultConfig->bitenc_depth))
-        {
-            DynamicPreprocessorFatalMessage("%s(%d) => SMTP: bitenc_decode_depth value %d in non-default config "
-                                           " cannot exceed default config's value.\n",
-                                           *(_dpd.config_file), *(_dpd.config_line), pPolicyConfig->bitenc_depth, defaultConfig->bitenc_depth);
+           pPolicyConfig->decode_conf = defaultConfig->decode_conf;
+           return;
         }
+        _dpd.fileAPI->check_decoding_conf(&(pPolicyConfig->decode_conf),
+                        &(defaultConfig->decode_conf), "SMTP");
 
     }
 }
@@ -584,9 +430,9 @@ void SMTP_PrintConfig(SMTPConfig *config)
 
     snprintf(buf, sizeof(buf) - 1, "    Ports: ");
 
-    for (i = 0; i < 65536; i++)
+    for(i = 0; i < 65536; i++)
     {
-        if (config->ports[i / 8] & (1 << (i % 8)))
+        if( isPortEnabled( config->ports, i ) )
         {
             _dpd.printfappend(buf, sizeof(buf) - 1, "%d ", i);
         }
@@ -629,7 +475,7 @@ void SMTP_PrintConfig(SMTPConfig *config)
     _dpd.logMsg("%s\n", buf);
 
     _dpd.logMsg("    Ignore Data: %s\n",
-                config->ignore_data ? "Yes" : "No");
+                config->decode_conf.ignore_data ? "Yes" : "No");
     _dpd.logMsg("    Ignore TLS Data: %s\n",
                 config->ignore_tls_data ? "Yes" : "No");
     _dpd.logMsg("    Ignore SMTP Alerts: %s\n",
@@ -734,66 +580,66 @@ void SMTP_PrintConfig(SMTPConfig *config)
             config->memcap);
 
     _dpd.logMsg("    MIME Max Mem: %d\n",
-            config->max_mime_mem);
+            config->decode_conf.max_mime_mem);
 
-    if(config->b64_depth > -1)
+    if(config->decode_conf.b64_depth > -1)
     {
         _dpd.logMsg("    Base64 Decoding: %s\n", "Enabled");
-        switch(config->b64_depth)
+        switch(config->decode_conf.b64_depth)
         {
             case 0:
                 _dpd.logMsg("    Base64 Decoding Depth: %s\n", "Unlimited");
                 break;
             default:
-                _dpd.logMsg("    Base64 Decoding Depth: %d\n", config->b64_depth);
+                _dpd.logMsg("    Base64 Decoding Depth: %d\n", config->decode_conf.b64_depth);
                 break;
         }
     }
     else
         _dpd.logMsg("    Base64 Decoding: %s\n", "Disabled");
 
-    if(config->qp_depth > -1)
+    if(config->decode_conf.qp_depth > -1)
     {
         _dpd.logMsg("    Quoted-Printable Decoding: %s\n","Enabled");
-        switch(config->qp_depth)
+        switch(config->decode_conf.qp_depth)
         {
             case 0:
                 _dpd.logMsg("    Quoted-Printable Decoding Depth: %s\n", "Unlimited");
                 break;
             default:
-                _dpd.logMsg("    Quoted-Printable Decoding Depth: %d\n", config->qp_depth);
+                _dpd.logMsg("    Quoted-Printable Decoding Depth: %d\n", config->decode_conf.qp_depth);
                 break;
         }
     }
     else
         _dpd.logMsg("    Quoted-Printable Decoding: %s\n", "Disabled");
 
-    if(config->uu_depth > -1)
+    if(config->decode_conf.uu_depth > -1)
     {
         _dpd.logMsg("    Unix-to-Unix Decoding: %s\n","Enabled");
-        switch(config->uu_depth)
+        switch(config->decode_conf.uu_depth)
         {
             case 0:
                 _dpd.logMsg("    Unix-to-Unix Decoding Depth: %s\n", "Unlimited");
                 break;
             default:
-                _dpd.logMsg("    Unix-to-Unix Decoding Depth: %d\n", config->uu_depth);
+                _dpd.logMsg("    Unix-to-Unix Decoding Depth: %d\n", config->decode_conf.uu_depth);
                 break;
         }
     }
     else
         _dpd.logMsg("    Unix-to-Unix Decoding: %s\n", "Disabled");
 
-    if(config->bitenc_depth > -1)
+    if(config->decode_conf.bitenc_depth > -1)
     {
         _dpd.logMsg("    Non-Encoded MIME attachment Extraction: %s\n","Enabled");
-        switch(config->bitenc_depth)
+        switch(config->decode_conf.bitenc_depth)
         {
             case 0:
                 _dpd.logMsg("    Non-Encoded MIME attachment Extraction Depth: %s\n", "Unlimited");
                 break;
             default:
-                _dpd.logMsg("    Non-Encoded MIME attachment Extraction Depth: %d\n", config->bitenc_depth);
+                _dpd.logMsg("    Non-Encoded MIME attachment Extraction Depth: %d\n", config->decode_conf.bitenc_depth);
                 break;
         }
     }
@@ -869,10 +715,9 @@ static int ProcessPorts(SMTPConfig *config, char *ErrorString, int ErrStrLen)
     }
 
     /* Since ports are specified, clear default ports */
-    config->ports[SMTP_DEFAULT_SERVER_PORT / 8] &= ~(1 << (SMTP_DEFAULT_SERVER_PORT % 8));
-    config->ports[XLINK2STATE_DEFAULT_PORT / 8] &= ~(1 << (XLINK2STATE_DEFAULT_PORT % 8));
-    config->ports[SMTP_DEFAULT_SUBMISSION_PORT / 8] &= ~(1 << (SMTP_DEFAULT_SUBMISSION_PORT % 8));
-
+    disablePort( config->ports, SMTP_DEFAULT_SERVER_PORT );
+    disablePort( config->ports, XLINK2STATE_DEFAULT_PORT );
+    disablePort( config->ports, SMTP_DEFAULT_SUBMISSION_PORT );
     while ((pcToken = strtok(NULL, CONF_SEPARATORS)) != NULL)
     {
         if(!strcmp(CONF_END_LIST, pcToken))
@@ -902,7 +747,7 @@ static int ProcessPorts(SMTPConfig *config, char *ErrorString, int ErrStrLen)
             return -1;
         }
 
-        config->ports[iPort / 8] |= (1 << (iPort % 8));
+        enablePort( config->ports, iPort );
         num_ports++;
     }
 
@@ -1232,74 +1077,6 @@ static int ProcessLogDepth(SMTPConfig *config, char *ErrorString, int ErrStrLen)
     return 0;
 }
 
-static int ProcessDecodeDepth(SMTPConfig *config, char *ErrorString, int ErrStrLen, char *decode_type, DecodeType type)
-{
-    char *endptr;
-    char *value;
-    int decode_depth = 0;
-    if (config == NULL)
-    {
-        snprintf(ErrorString, ErrStrLen, "SMTP config is NULL.\n");
-        return -1;
-    }
-
-    value = strtok(NULL, CONF_SEPARATORS);
-    if ( value == NULL )
-    {
-        snprintf(ErrorString, ErrStrLen,
-            "Invalid format for SMTP config option '%s'.", decode_type);
-        return -1;
-    }
-    decode_depth = strtol(value, &endptr, 10);
-
-    if(*endptr)
-    {
-        snprintf(ErrorString, ErrStrLen,
-            "Invalid format for SMTP config option '%s'.", decode_type);
-        return -1;
-    }
-    if(decode_depth < MIN_DEPTH || decode_depth > MAX_DEPTH)
-    {
-        snprintf(ErrorString, ErrStrLen,
-                "Invalid value for SMTP config option '%s'."
-                "It should range between %d and %d.",
-                decode_type, MIN_DEPTH, MAX_DEPTH);
-        return -1;
-    }
-
-    switch(type)
-    {
-        case DECODE_B64:
-                if((decode_depth > 0) && (decode_depth & 3))
-                {
-                    decode_depth += 4 - (decode_depth & 3);
-                    if(decode_depth > MAX_DEPTH )
-                    {
-                        decode_depth = decode_depth - 4;
-                    }
-                    _dpd.logMsg("WARNING: %s(%d) => SMTP: 'b64_decode_depth' is not a multiple of 4. "
-                            "Rounding up to the next multiple of 4. The new 'b64_decode_depth' is %d.\n",
-                            *(_dpd.config_file), *(_dpd.config_line), decode_depth);
-                }
-                config->b64_depth = decode_depth;
-                break;
-        case DECODE_QP:
-                config->qp_depth = decode_depth;
-                break;
-        case DECODE_UU:
-                config->uu_depth = decode_depth;
-                break;
-        case DECODE_BITENC:
-                config->bitenc_depth = decode_depth;
-                break;
-        default:
-                return -1;
-    }
-
-    return 0;
-}
-
-
 
 /*
 **  NAME
@@ -1452,12 +1229,12 @@ static int ProcessXlink2State(SMTPConfig *config, char *ErrorString, int ErrStrL
         if ( !strcasecmp(CONF_DISABLE, pcToken) )
         {
             config->alert_xlink2state = 0;
-            config->ports[XLINK2STATE_DEFAULT_PORT / 8] &= ~(1 << (XLINK2STATE_DEFAULT_PORT % 8));
+            disablePort( config->ports, XLINK2STATE_DEFAULT_PORT );
         }
         else if ( !strcasecmp(CONF_ENABLE, pcToken) )
         {
             config->alert_xlink2state = 1;
-            config->ports[XLINK2STATE_DEFAULT_PORT / 8] |= 1 << (XLINK2STATE_DEFAULT_PORT % 8);
+            disablePort( config->ports, XLINK2STATE_DEFAULT_PORT );
         }
         else if ( !strcasecmp(CONF_INLINE_DROP, pcToken) )
         {
@@ -1483,4 +1260,3 @@ static int ProcessXlink2State(SMTPConfig *config, char *ErrorString, int ErrStrL
 
     return 0;
 }
-
