@@ -24,10 +24,11 @@
  */
 
 
-#ifndef __IMAP_CONFIG_H__
-#define __IMAP_CONFIG_H__
+#ifndef __FILE_MIME_CONFIG_H__
+#define __FILE_MIME_CONFIG_H__
 
 #include "file_api.h"
+#include "file_mail_common.h"
 
 /* Function prototypes  */
 void set_mime_decode_config_defauts(DecodeConfig *decode_conf);
@@ -36,5 +37,6 @@ int parse_mime_decode_args(DecodeConfig *decode_conf, char *arg, const char *pre
 bool is_decoding_enabled(DecodeConfig *decode_conf);
 bool is_mime_log_enabled(MAIL_LogConfig *log_config);
 bool is_decoding_conf_changed(DecodeConfig *configNext, DecodeConfig *config, const char *preproc_name);
+bool check_decode_config(DecodeConfig *currentConfig, DecodeConfig *defaultConfig, const char *preproc_name);
 #endif
 
