@@ -147,7 +147,19 @@ static HI_EVENT_INFO server_event_info[HI_EO_SERVER_EVENT_NUM] = {
     {HI_EO_SERVER_JS_EXCESS_WS, HI_EO_MED_PRIORITY,
         HI_EO_SERVER_JS_EXCESS_WS_STR},
     {HI_EO_SERVER_MIXED_ENCODINGS, HI_EO_MED_PRIORITY,
-        HI_EO_SERVER_MIXED_ENCODINGS_STR}
+        HI_EO_SERVER_MIXED_ENCODINGS_STR},
+    {HI_EO_SERVER_SWF_ZLIB_FAILURE, HI_EO_MED_PRIORITY,
+        HI_EO_SERVER_SWF_ZLIB_FAILURE_STR},
+    {HI_EO_SERVER_SWF_LZMA_FAILURE, HI_EO_MED_PRIORITY,
+        HI_EO_SERVER_SWF_LZMA_FAILURE_STR},
+    {HI_EO_SERVER_PDF_DEFL_FAILURE, HI_EO_MED_PRIORITY,
+        HI_EO_SERVER_PDF_DEFL_FAILURE_STR},
+    {HI_EO_SERVER_PDF_UNSUP_COMP_TYPE, HI_EO_MED_PRIORITY,
+        HI_EO_SERVER_PDF_UNSUP_COMP_TYPE_STR},
+    {HI_EO_SERVER_PDF_CASC_COMP, HI_EO_MED_PRIORITY,
+        HI_EO_SERVER_PDF_CASC_COMP_STR},
+    {HI_EO_SERVER_PDF_PARSE_FAILURE, HI_EO_MED_PRIORITY,
+        HI_EO_SERVER_PDF_PARSE_FAILURE_STR}
 };
 
 /*
