@@ -81,6 +81,12 @@ typedef enum _HI_EVENTS
     HI_EO_SERVER_JS_OBFUSCATION_EXCD,
     HI_EO_SERVER_JS_EXCESS_WS,
     HI_EO_SERVER_MIXED_ENCODINGS,
+    HI_EO_SERVER_SWF_ZLIB_FAILURE,
+    HI_EO_SERVER_SWF_LZMA_FAILURE,
+    HI_EO_SERVER_PDF_DEFL_FAILURE,
+    HI_EO_SERVER_PDF_UNSUP_COMP_TYPE,
+    HI_EO_SERVER_PDF_CASC_COMP,
+    HI_EO_SERVER_PDF_PARSE_FAILURE,
     HI_EO_SERVER_EVENT_NUM
 }HI_EVENTS;
 
@@ -183,7 +189,19 @@ typedef enum _HI_EVENTS
     "(http_inspect) JAVASCRIPT WHITESPACES EXCEEDS MAX ALLOWED"
 #define HI_EO_SERVER_MIXED_ENCODINGS_STR                \
     "(http_inspect) MULTIPLE ENCODINGS WITHIN JAVASCRIPT OBFUSCATED DATA"
-
+#define HI_EO_SERVER_SWF_ZLIB_FAILURE_STR               \
+    "(http_inspect) HTTP_RESPONSE SWF FILE ZLIB DECOMPRESSION FAILURE"
+#define HI_EO_SERVER_SWF_LZMA_FAILURE_STR               \
+    "(http_inspect) HTTP_RESPONSE SWF FILE LZMA DECOMPRESSION FAILURE"
+#define HI_EO_SERVER_PDF_DEFL_FAILURE_STR               \
+    "(http_inspect) HTTP_RESPONSE PDF FILE DEFLATE DECOMPRESSION FAILURE"
+#define HI_EO_SERVER_PDF_UNSUP_COMP_TYPE_STR            \
+    "(http_inspect) HTTP_RESPONSE PDF FILE UNSUPPORTED COMPRESSION TYPE"
+#define HI_EO_SERVER_PDF_CASC_COMP_STR                  \
+    "(http_inspect) HTTP_RESPONSE PDF FILE CASCADED COMPRESSION"
+#define HI_EO_SERVER_PDF_PARSE_FAILURE_STR              \
+    "(http_inspect) HTTP_RESPONSE PDF FILE PARSE FAILURE"
+ 
 /*
 **  Event Priorities
 */
