@@ -142,6 +142,7 @@
 #include "sf_types.h"
 #include "sfPolicy.h"
 #include "sfPolicyUserData.h"
+#include "session_api.h"
 
 #define BACKORIFICE_DEFAULT_KEY   31337
 #define BACKORIFICE_MAGIC_SIZE    8
@@ -281,7 +282,8 @@ static void BoInit(struct _SnortConfig *sc, char *args)
     ProcessArgs(pPolicyConfig, args);
 
     /* Set the preprocessor function into the function list */
-    AddFuncToPreprocList(sc, BoFind, PRIORITY_LAST, PP_BO, PROTO_BIT__UDP);
+    AddFuncToPreprocList(sc, BoFind, PRIORITY_APPLICATION, PP_BO, PROTO_BIT__UDP);
+    session_api->enable_preproc_all_ports( sc, PP_BO, PROTO_BIT__UDP );
 }
 
 
@@ -555,7 +557,7 @@ static void BoFind(Packet *p, void *context)
     BoConfig *bo = NULL;
     PROFILE_VARS;
 
-    sfPolicyUserPolicySet (bo_config, getRuntimePolicy());
+    sfPolicyUserPolicySet (bo_config, getNapRuntimePolicy());
     bo = (BoConfig *)sfPolicyUserDataGetCurrent(bo_config);
 
     /* Not configured in this policy */
@@ -898,6 +900,7 @@ static void BoReload(struct _SnortConfig *sc, char *args, void **new_config)
     ProcessArgs(pPolicyConfig, args);
 
     AddFuncToPreprocList(sc, BoFind, PRIORITY_LAST, PP_BO, PROTO_BIT__UDP);
+    session_api->enable_preproc_all_ports( sc, PP_BO, PROTO_BIT__UDP );
 }
 
 static void * BoReloadSwap(struct _SnortConfig *sc, void *swap_config)
