@@ -24,6 +24,12 @@
 #ifndef __STR_SEARCH_H__
 #define __STR_SEARCH_H__
 
+#include "mpse_methods.h"
+
+/*search pattern case sensitivity */
+#define STR_SEARCH_CASE_SENSITIVE 0
+#define STR_SEARCH_CASE_INSENSITIVE 1
+
 /* Function prototypes  */
 typedef int (*MatchFunction)(void *, void *, int, void *, void *);
 
@@ -39,10 +45,13 @@ int  SearchFindString(unsigned int mpse_id, const char *str, unsigned int str_le
 
 
 void * SearchInstanceNew( void );
+void * SearchInstanceNewEx( unsigned method );
 void   SearchInstanceFree( void * insance );
 void   SearchInstanceAdd( void * instance, const char *pat, unsigned int pat_len, int id);
+void   SearchInstanceAddEx( void * instance, const char *pat, unsigned int pat_len, void* id, unsigned nocase);
 void   SearchInstancePrepPatterns( void * instance );
 int    SearchInstanceFindString( void * instance, const char *str, unsigned int str_len, int confine, MatchFunction);
+int    SearchInstanceFindStringAll( void * instance, const char *str, unsigned int str_len, int confine, MatchFunction, void *userData);
 int    SearchInstanceSFindString( void * instance, const char *str, unsigned int str_len, int confine, MatchFunction, int *state);
 
 typedef struct _search_api
@@ -66,10 +75,13 @@ typedef struct _search_api
     int (*search_put_handle)(unsigned int);
 
     void * (*search_instance_new)(void);
+    void * (*search_instance_new_ex)(unsigned method);
     void   (*search_instance_free)(void * instance);
     void   (*search_instance_add) (void * instance, const char *s, unsigned int s_len, int s_id);
+    void   (*search_instance_add_ex) (void * instance, const char *s, unsigned int s_len, void* s_id, unsigned nocase);
     void   (*search_instance_prep)(void * instance );
     int    (*search_instance_find)(void * instance, const char *s, unsigned int s_len, int confine, MatchFunction); 
+    int    (*search_instance_find_all)(void * instance, const char *s, unsigned int s_len, int confine, MatchFunction, void *userData); 
     char * (*search_instance_find_end)(char *match_ptr, int buflen, char *search_str, int search_len);  
     int    (*stateful_search_instance_find)(void * instance, const char *s, unsigned int s_len, int confine, MatchFunction, int *state); 
     
