@@ -43,8 +43,7 @@ int sf_sdlist_init(sfSDList *list, void (*destroy)(void *data));
 int sf_sdlist_delete(sfSDList *list);
 
 /* insert item, putting data in container */
-int sf_sdlist_insert_next(sfSDList *list, SDListItem *item, void *data,
-                          SDListItem *container);
+int sf_sdlist_insert_next(sfSDList *list, SDListItem *item, void *data, SDListItem *container);
 
 /* remove the item after the item */
 int sf_sdlist_remove_next(sfSDList *list, SDListItem *item);
@@ -57,4 +56,21 @@ int sf_sdlist_append(sfSDList *list, void *data, SDListItem *container);
 
 void print_sdlist(sfSDList *list);
 
+// list functions that handle memory allocation for inserted list items
+int sf_sdlist_ins_next(sfSDList *list, SDListItem *item, const void *data);
+int sf_sdlist_ins_prev(sfSDList *list, SDListItem *item, const void *data);
+int sf_sdlist_rem_item(sfSDList *list, SDListItem *item, void **data);
+int sf_sdlist_purge(sfSDList *list);
+
+
+// macro implementation of simple doubly linked list operations
+#define sf_sdlist_size(list) ((list)->size)
+#define sf_sdlist_head(list) ((list)->head)
+#define sf_sdlist_tail(list) ((list)->tail)
+#define sf_sdlist_is_head(item) ((item)->prev == NULL ? 1 : 0)
+#define sf_sdlist_is_tail(item) ((item)->next == NULL ? 1 : 0)
+#define sf_sdlist_data(item) ((item)->data)
+#define sf_sdlist_next(item) ((item)->next)
+#define sf_sdlist_prev(item) ((item)->prev)
+
 #endif /* _SF_DLIST */
