@@ -154,15 +154,18 @@
 
 #include "sf_types.h"
 
+#ifndef DYNAMIC_PREPROC_CONTEXT
 #define BNFA_TRACK_Q
 
 #ifdef BNFA_TRACK_Q
 # include "snort.h"
 #endif
+#endif //DYNAMIC_PREPROC_CONTEXT
 
 #include "bnfa_search.h"
 #include "snort_debug.h"
 #include "util.h"
+#include "sf_dynamic_preprocessor.h"
 
 /*
  * Used to initialize last state, states are limited to 0-16M
@@ -514,6 +517,7 @@ int bnfaBuildMatchStateTrees(bnfa_struct_t *bnfa,
     return cnt;
 }
 
+#ifndef DYNAMIC_PREPROCESSOR_CONTEXT
 static
 int bnfaBuildMatchStateTreesWithSnortConf(struct _SnortConfig *sc, bnfa_struct_t *bnfa,
                                           int (*build_tree)(struct _SnortConfig *, void *id, void **existing_tree),
@@ -555,6 +559,7 @@ int bnfaBuildMatchStateTreesWithSnortConf(struct _SnortConfig *sc, bnfa_struct_t
 
     return cnt;
 }
+#endif //DYNAMIC_PREPROCESSOR_CONTEXT
 
 #ifdef ALLOW_LIST_PRINT
 /*
@@ -1660,6 +1665,7 @@ bnfaCompile (bnfa_struct_t * bnfa,
     return 0;
 }
 
+#ifndef DYNAMIC_PREPROCESSOR_CONTEXT
 int
 bnfaCompileWithSnortConf (struct _SnortConfig *sc, bnfa_struct_t * bnfa,
                           int (*build_tree)(struct _SnortConfig *, void * id, void **existing_tree),
@@ -1676,6 +1682,7 @@ bnfaCompileWithSnortConf (struct _SnortConfig *sc, bnfa_struct_t * bnfa,
     }
     return 0;
 }
+#endif //DYNAMIC_PREPROCESSOR_CONTEXT
 
 #ifdef ALLOW_NFA_FULL
 
