@@ -82,7 +82,6 @@ typedef int (*MatchFunc)(void * id, void *tree, int index, void *data, void *neg
 
 /* GLOBALS ********************************************************************/
 static CpaInstanceHandle ipm_instance = NULL;  /* instance handle */
-static IntelPmHandles *ipm_handles = NULL;
 
 /* XXX Temporary stat for Intel */
 //static uint64_t intel_pm_search_buf_sizes[65536];
@@ -95,7 +94,7 @@ static void IntelPmSearchCallback(const CpaInstanceHandle, CpaPmMatchCtx *);
 static inline void IntelPmInitQueue(IntelPmMatchQueue *);
 static inline int IntelPmAddQueue(IntelPmMatchQueue *, void *);
 static inline unsigned int IntelPmProcessQueue(IntelPmMatchQueue *, MatchFunc, void *);
-static void IntelPmRelease(IntelPmHandles *);
+
 
 /* FUNCTIONS ******************************************************************/
 static inline const char * GetCpaStatusStr(CpaStatus status)
@@ -206,7 +205,7 @@ void * IntelPmNew(SnortConfig *sc, void (*user_free)(void *p), void (*option_tre
     CpaStatus status;
     IntelPm *ipm = (IntelPm *)SnortAlloc(sizeof(IntelPm));
 
-    if (ipm_handles == NULL)
+    if (sc->ipm_handles == NULL)
     {
         CpaPmPdbPatternSetHandle patternSetHandle;
 
@@ -214,11 +213,12 @@ void * IntelPmNew(SnortConfig *sc, void (*user_free)(void *p), void (*option_tre
         if (status != CPA_STATUS_SUCCESS)
             FatalError("cpaPmPdbCreatePatternSet() failed: %s\n", GetCpaStatusStr(status));
 
-        ipm_handles = (IntelPmHandles *)SnortAlloc(sizeof(IntelPmHandles));
-        ipm_handles->psh = patternSetHandle;
-        ipm_handles->pdbh = NULL;
-        ipm_handles->pgids = 1;
-        ipm_handles->pids = 0;
+        sc->ipm_handles = (IntelPmHandles *)SnortAlloc(sizeof(IntelPmHandles));
+        sc->ipm_handles->psh = patternSetHandle;
+        sc->ipm_handles->pdbh = NULL;
+        sc->ipm_handles->pgids = 1;
+        sc->ipm_handles->pids = 0;
+        sc->ipm_handles->refs = 1;  //sc has a reference
 
         //memset(intel_pm_search_buf_sizes, 0, sizeof(intel_pm_search_buf_sizes));
     }
@@ -228,15 +228,14 @@ void * IntelPmNew(SnortConfig *sc, void (*user_free)(void *p), void (*option_tre
     ipm->neg_list_free = neg_list_free;
     ipm->match_queue = SnortAlloc(sizeof(IntelPmMatchQueue));
 
-    ipm->handles = ipm_handles;
-    ipm_handles->refs++;
+    ipm->handles = sc->ipm_handles;
+    sc->ipm_handles->refs++;
 
     return (void *)ipm;
 }
 
 void IntelPmDelete(IntelPm *ipm)
 {
-    IntelPmHandles *handles;
     int i;
 
     if (ipm == NULL)
@@ -261,21 +260,22 @@ void IntelPmDelete(IntelPm *ipm)
 
     free(ipm->pattern_array);
 
-    handles = (IntelPmHandles *)ipm->handles;
-    handles->refs--;
-    if (handles->refs == 0)
-        IntelPmRelease(handles);
+    IntelPmRelease(ipm->handles);
 
     free(ipm);
 }
 
-static void IntelPmRelease(IntelPmHandles *handles)
+int IntelPmRelease(IntelPmHandles *handles)
 {
     CpaStatus status;
     int i;
 
     if (handles == NULL)
-        return;
+        return -1;
+
+    handles->refs--;
+    if (handles->refs != 0)
+        return handles->refs;
 
     for (i = 0; i < handles->pm_mtchs_len; i++)
     {
@@ -305,9 +305,7 @@ static void IntelPmRelease(IntelPmHandles *handles)
     free(handles->ipms);
     free(handles->pm_mtchs);
     free(handles);
-
-    if ( handles == ipm_handles )
-        ipm_handles = NULL;
+    return 0;
 }
 
 int IntelPmAddPattern(SnortConfig *sc, IntelPm *ipm, unsigned char *pat, int pat_len,
@@ -318,18 +316,18 @@ int IntelPmAddPattern(SnortConfig *sc, IntelPm *ipm, unsigned char *pat, int pat
     CpaStatus status;
     IntelPmPattern *ipp;
 
-    if ((ipm == NULL) || (ipm_handles == NULL))
+    if ((ipm == NULL) || (sc->ipm_handles == NULL))
         return -1;
 
     if (!ipm->patternGroupId)
     {
-        ipm->patternGroupId = ipm_handles->pgids++;
+        ipm->patternGroupId = sc->ipm_handles->pgids++;
         ipm->patternIds = 1;
     }
 
     status = cpaPmPdbAddPattern(
             ipm_instance,
-            ipm_handles->psh,
+            sc->ipm_handles->psh,
             ipm->patternIds,
             patternOptions,
             pat_len,
@@ -368,8 +366,8 @@ int IntelPmAddPattern(SnortConfig *sc, IntelPm *ipm, unsigned char *pat, int pat
     ipp->id = pat_id;
     ipp->patternId = ipm->patternIds++;
 
-    ipm_handles->pids++;
-    ipm_handles->pcs += pat_len;
+    sc->ipm_handles->pids++;
+    sc->ipm_handles->pcs += pat_len;
 
     return 0;
 }
@@ -404,66 +402,66 @@ int IntelPmFinishGroup(SnortConfig *sc, IntelPm *ipm,
     if (status != CPA_STATUS_SUCCESS)
         FatalError("cpaPmCreateSessionCtx() failed: %s\n", GetCpaStatusStr(status));
 
-    if (ipm_handles->ipms == NULL)
+    if (sc->ipm_handles->ipms == NULL)
     {
-        ipm_handles->ipms = (IntelPm **)SnortAlloc(
+        sc->ipm_handles->ipms = (IntelPm **)SnortAlloc(
                 sizeof(IntelPm *) * GROUP_ARRAY_ALLOC_SIZE);
-        ipm_handles->ipms_len = GROUP_ARRAY_ALLOC_SIZE;
+        sc->ipm_handles->ipms_len = GROUP_ARRAY_ALLOC_SIZE;
     }
-    else if (ipm->patternGroupId >= ipm_handles->ipms_len)
+    else if (ipm->patternGroupId >= sc->ipm_handles->ipms_len)
     {
         IntelPm **tmp = (IntelPm **)SnortAlloc(
                 sizeof(IntelPm *) * (ipm->patternGroupId + GROUP_ARRAY_ALLOC_SIZE));
-        memcpy((void *)tmp, ipm_handles->ipms, ipm_handles->ipms_len * sizeof(IntelPm *));
-        free(ipm_handles->ipms);
-        ipm_handles->ipms = tmp;
-        ipm_handles->ipms_len = ipm->patternGroupId + GROUP_ARRAY_ALLOC_SIZE;
+        memcpy((void *)tmp, sc->ipm_handles->ipms, sc->ipm_handles->ipms_len * sizeof(IntelPm *));
+        free(sc->ipm_handles->ipms);
+        sc->ipm_handles->ipms = tmp;
+        sc->ipm_handles->ipms_len = ipm->patternGroupId + GROUP_ARRAY_ALLOC_SIZE;
     }
 
-    ipm_handles->ipms[ipm->patternGroupId] = ipm;
+    sc->ipm_handles->ipms[ipm->patternGroupId] = ipm;
 
     return 0;
 }
 
 void IntelPmCompile(SnortConfig *sc)
 {
-    if ((ipm_instance == NULL) || (ipm_handles == NULL)
-            || (ipm_handles->psh == NULL))
+    if ((ipm_instance == NULL) || (sc->ipm_handles == NULL)
+            || (sc->ipm_handles->psh == NULL))
     {
         return;
     }
 
-    if (ipm_handles->pdbh == NULL)
+    if (sc->ipm_handles->pdbh == NULL)
     {
         CpaStatus status;
         Cpa16U patternGroup;
         Cpa32U numMatchStates;
 
-        status = cpaPmPdbCompile(ipm_instance, ipm_handles->psh,
-                CPA_PM_COMPILE_OPTION_CONSOLIDATE, NULL, &ipm_handles->pdbh);
+        status = cpaPmPdbCompile(ipm_instance, sc->ipm_handles->psh,
+                CPA_PM_COMPILE_OPTION_CONSOLIDATE, NULL, &sc->ipm_handles->pdbh);
         if (status != CPA_STATUS_SUCCESS)
             FatalError("cpaPmPdbCompile() failed: %s\n", GetCpaStatusStr(status));
 
-        status = cpaPmMsoGetNumMatchStates(ipm_instance, ipm_handles->pdbh, &numMatchStates);
+        status = cpaPmMsoGetNumMatchStates(ipm_instance, sc->ipm_handles->pdbh, &numMatchStates);
         if (status != CPA_STATUS_SUCCESS)
             FatalError("cpaPmMsoGetNumMatchStates() failed: %s\n", GetCpaStatusStr(status));
 
         /* Hack because the last match state is returned instead of the
          * number of match states */
         numMatchStates += 1;
-        ipm_handles->pm_mtchs = (IntelPmMatchState *)SnortAlloc(numMatchStates * sizeof(IntelPmMatchState));
-        ipm_handles->pm_mtchs_len = numMatchStates;
+        sc->ipm_handles->pm_mtchs = (IntelPmMatchState *)SnortAlloc(numMatchStates * sizeof(IntelPmMatchState));
+        sc->ipm_handles->pm_mtchs_len = numMatchStates;
 
-        for (patternGroup = 1; patternGroup < ipm_handles->pgids; patternGroup++)
+        for (patternGroup = 1; patternGroup < sc->ipm_handles->pgids; patternGroup++)
         {
             CpaPmMsoMatchStateIter matchStateIter = NULL;
             Cpa32U matchStateId;
-            IntelPm *ipm = ipm_handles->ipms[patternGroup];
+            IntelPm *ipm = sc->ipm_handles->ipms[patternGroup];
 
             if (ipm == NULL)
                 continue;
 
-            status = cpaPmMsoGetFirstMatchState(ipm_instance, ipm_handles->pdbh,
+            status = cpaPmMsoGetFirstMatchState(ipm_instance, sc->ipm_handles->pdbh,
                     patternGroup, &matchStateIter, &matchStateId);
 
             if (status != CPA_STATUS_SUCCESS)
@@ -478,7 +476,7 @@ void IntelPmCompile(SnortConfig *sc)
                 void *neg_list = NULL;
                 void *user_data = NULL;
 
-                status = cpaPmMsoGetFirstPatternId(ipm_instance, ipm_handles->pdbh,
+                status = cpaPmMsoGetFirstPatternId(ipm_instance, sc->ipm_handles->pdbh,
                         matchStateIter, &patternIdIter, &patternID);
 
                 if (status != CPA_STATUS_SUCCESS)
@@ -495,7 +493,7 @@ void IntelPmCompile(SnortConfig *sc)
                     else
                         ipm->build_tree(sc, ipp->user_data, &rule_option_tree);
 
-                    status = cpaPmMsoGetNextPatternId(ipm_instance, ipm_handles->pdbh,
+                    status = cpaPmMsoGetNextPatternId(ipm_instance, sc->ipm_handles->pdbh,
                             &patternIdIter, &patternID);
 
                     if (status != CPA_STATUS_SUCCESS)
@@ -506,16 +504,16 @@ void IntelPmCompile(SnortConfig *sc)
                 {
                     ipm->build_tree(sc, NULL, &rule_option_tree);
 
-                    ipm_handles->pm_mtchs[matchStateId].user_data = user_data;
-                    ipm_handles->pm_mtchs[matchStateId].neg_list = neg_list;
-                    ipm_handles->pm_mtchs[matchStateId].rule_option_tree = rule_option_tree;
+                    sc->ipm_handles->pm_mtchs[matchStateId].user_data = user_data;
+                    sc->ipm_handles->pm_mtchs[matchStateId].neg_list = neg_list;
+                    sc->ipm_handles->pm_mtchs[matchStateId].rule_option_tree = rule_option_tree;
 
-                    ipm_handles->pm_mtchs[matchStateId].user_free = ipm->user_free;
-                    ipm_handles->pm_mtchs[matchStateId].option_tree_free = ipm->option_tree_free;
-                    ipm_handles->pm_mtchs[matchStateId].neg_list_free = ipm->neg_list_free;
+                    sc->ipm_handles->pm_mtchs[matchStateId].user_free = ipm->user_free;
+                    sc->ipm_handles->pm_mtchs[matchStateId].option_tree_free = ipm->option_tree_free;
+                    sc->ipm_handles->pm_mtchs[matchStateId].neg_list_free = ipm->neg_list_free;
                 }
 
-                status = cpaPmMsoGetNextMatchState(ipm_instance, ipm_handles->pdbh,
+                status = cpaPmMsoGetNextMatchState(ipm_instance, sc->ipm_handles->pdbh,
                         patternGroup, &matchStateIter, &matchStateId);
 
                 if (status != CPA_STATUS_SUCCESS)
@@ -528,16 +526,18 @@ void IntelPmCompile(SnortConfig *sc)
 void IntelPmActivate(SnortConfig *sc)
 {
     CpaStatus status;
+    IntelPmHandles *handles = sc->ipm_handles;
 
-    if ((ipm_instance == NULL) || (ipm_handles == NULL))
+    sc->ipm_handles = NULL;
+    if (IntelPmRelease(handles) <= 0)
         return;
 
-    status = cpaPmActivatePdb(ipm_instance, ipm_handles->pdbh, NULL);
+    if (ipm_instance == NULL)
+        return;
+
+    status = cpaPmActivatePdb(ipm_instance, handles->pdbh, NULL);
     if (status != CPA_STATUS_SUCCESS)
         FatalError("cpaPmPdbActivate() failed: %s\n", GetCpaStatusStr(status));
-
-    /* All ipms should have a reference to this now.  Need this for reloading */
-    ipm_handles = NULL;
 }
 
 static void IntelPmSearchCallback(const CpaInstanceHandle instanceHandle,
@@ -622,13 +622,13 @@ int IntelPmPrintInfo(IntelPm *ipm)
 
 void IntelPmPrintSummary(SnortConfig *sc)
 {
-    if (ipm_handles == NULL)
+    if (sc->ipm_handles == NULL)
         return;
 
     LogMessage("+-[Intel PM Search Info Summary]------------------\n");
-    LogMessage("| Instances        : %u\n", ipm_handles->pgids - 1);  /* pattern groups start at 1 */
-    LogMessage("| Patterns         : %u\n", ipm_handles->pids);
-    LogMessage("| Pattern Chars    : %u\n", ipm_handles->pcs);
+    LogMessage("| Instances        : %u\n", sc->ipm_handles->pgids - 1);  /* pattern groups start at 1 */
+    LogMessage("| Patterns         : %u\n", sc->ipm_handles->pids);
+    LogMessage("| Pattern Chars    : %u\n", sc->ipm_handles->pcs);
     LogMessage("+-------------------------------------------------\n");
 }
 
