@@ -30,6 +30,8 @@
 #include "snort_debug.h"
 #include "sfrt.h"
 
+tSfPolicyId napRuntimePolicyId = 0;
+tSfPolicyId ipsRuntimePolicyId = 0;
 
 static inline int IsBound (
     tSfPolicyId id
@@ -242,7 +244,7 @@ int sfVlanAddBinding(tSfPolicyConfig *config, int vlanId, char *fileName)
 {
     tSfPolicyId policyId;
 
-    if (config == NULL)
+    if (config == NULL || vlanId >= SF_VLAN_BINDING_MAX)
         return -1;
 
     //create a policyId
@@ -262,7 +264,14 @@ int sfVlanAddBinding(tSfPolicyConfig *config, int vlanId, char *fileName)
 
 tSfPolicyId sfVlanGetBinding(tSfPolicyConfig *config, int vlanId)
 {
-    tSfPolicyId policyId = config->vlanBindings[vlanId];
+    tSfPolicyId policyId;
+
+    if(vlanId >= SF_VLAN_BINDING_MAX){
+        //invalid policyid will never be bound. return default
+        return config->defaultPolicyId;
+    }
+    
+    policyId = config->vlanBindings[vlanId];
 
     if ( NotBound(policyId) )
     {
@@ -276,6 +285,8 @@ tSfPolicyId sfVlanGetBinding(tSfPolicyConfig *config, int vlanId)
 void sfVlanDeleteBinding(tSfPolicyConfig *config, int vlanId)
 {
     tSfPolicyId policyId;
+    if(vlanId >= SF_VLAN_BINDING_MAX)
+        return; //invalid, can't delete
 
     if ((config == NULL) || (vlanId < 0))
         return;
@@ -293,7 +304,7 @@ int sfPolicyIdAddBinding(tSfPolicyConfig *config, int parsedPolicyId, char *file
 {
     tSfPolicyId policyId;
 
-    if (config == NULL)
+    if (config == NULL || parsedPolicyId >= SF_POLICY_ID_BINDING_MAX)
         return -1;
 
     //create a policyId
@@ -313,7 +324,13 @@ int sfPolicyIdAddBinding(tSfPolicyConfig *config, int parsedPolicyId, char *file
 
 tSfPolicyId sfPolicyIdGetBinding(tSfPolicyConfig *config, int parsedPolicyId)
 {
-    tSfPolicyId policyId = config->policyIdBindings[parsedPolicyId];
+    tSfPolicyId policyId;
+
+    if(parsedPolicyId >= SF_POLICY_ID_BINDING_MAX){
+        //invalid policyid will never be bound. return default
+        return config->defaultPolicyId;
+    }
+    policyId = config->policyIdBindings[parsedPolicyId];
 
     if ( NotBound(policyId) )
     {
@@ -328,6 +345,9 @@ void sfPolicyIdDeleteBinding(tSfPolicyConfig *config, int parsedPolicyId)
 {
     tSfPolicyId policyId;
 
+    if(parsedPolicyId >= SF_POLICY_ID_BINDING_MAX)
+        return; //invalid, can't delete
+
     if ((config == NULL) || (parsedPolicyId < 0))
         return;
 
