@@ -33,9 +33,9 @@
 #define SF_POLICY_ID_BINDING_MAX 4096
 #define SF_NETWORK_BINDING_MAX 4096
 #define SF_POLICY_UNBOUND 0xffffffff
+#define SF_DEFAULT_POLICY_ID 0
 
-
-//vlan id or address range is reduced to policy id. and subsequent processing is done using policy id only.
+/*vlan id or address range is reduced to policy id. and subsequent processing is done using policy id only. */
 
 typedef struct
 {
@@ -74,10 +74,6 @@ typedef struct
 
 } tSfPolicyConfig;
 
-
-extern tSfPolicyId runtimePolicyId;
-extern tSfPolicyId parserPolicyId;
-
 tSfPolicyConfig * sfPolicyInit(
     void
     );
@@ -173,7 +169,7 @@ static inline tSfPolicyId sfPolicyNumAllocated(
     return config->numAllocatedPolicies;
 }
 
-//dynamic array functions
+/*dynamic array functions */
 int sfDynArrayCheckBounds (
         void ** dynArray,
         unsigned int index,
