@@ -79,12 +79,12 @@ typedef struct _ip {
         u_int8_t  u6_addr8[16];
         u_int16_t u6_addr16[8];
         u_int32_t u6_addr32[4];
-//        u_int64_t    u6_addr64[2];
+/*        u_int64_t    u6_addr64[2]; */
     } ip;
     #define ip8  ip.u6_addr8
     #define ip16 ip.u6_addr16
     #define ip32 ip.u6_addr32
-//    #define ip64 ip.u6_addr64
+/*    #define ip64 ip.u6_addr64 */
 } sfip_t;
 
 typedef enum _return_values {
@@ -147,7 +147,7 @@ static inline unsigned int sfip_size(sfip_t* ipt)
 /* Returns the family of "ip", either AF_INET or AF_INET6 */
 /* XXX This is a performance critical function,
 *  need to determine if it's safe to not check these pointers */
-// ARG_CHECK1(ip, 0);
+/* ARG_CHECK1(ip, 0); */
 #define sfip_family(ip) ip->family
 
 /* Returns the number of bits used for masking "ip" */
@@ -167,7 +167,7 @@ static inline void sfip_set_bits(sfip_t *p, int bits) {
 }
 
 /* Returns the raw IP address as an in6_addr */
-//inline struct in6_addr sfip_to_raw(sfip_t *);
+/*inline struct in6_addr sfip_to_raw(sfip_t *); */
 
 
 
@@ -181,7 +181,7 @@ SFIP_RET sfip_contains(const sfip_t *net, const sfip_t *ip);
 /* XXX This is a performance critical function, \
  *  need to determine if it's safe to not check these pointers */\
 static inline int sfip_is_set(const sfip_t *ip) {
-//    ARG_CHECK1(ip, -1);
+/*    ARG_CHECK1(ip, -1); */
     return ip->ip32[0] ||
             ( (ip->family == AF_INET6) &&
               (ip->ip32[1] ||
@@ -510,5 +510,5 @@ void sfip_ntop(const sfip_t *ip, char *buf, int bufsize);
 
 SFIP_RET sfip_convert_ip_text_to_binary( const int, char *src, void *dst );
 
-#endif // SF_IP_H
+#endif /* SF_IP_H */
 
