@@ -47,8 +47,8 @@
 #define SFGHASH_OK        0
 #define SFGHASH_INTABLE   1
 
-/* 
-*  Flags for ghash_new: userkeys 
+/*
+*  Flags for ghash_new: userkeys
 */
 #define GH_COPYKEYS 0
 #define GH_USERKEYS 1
@@ -60,9 +60,9 @@ typedef struct _sfghash_node
 {
   struct _sfghash_node * next, * prev;
 
-  void * key;   /* Copy of, or Pointer to, the Users key */
-  void * data;  /* Pointer to the users data, this is never copied! */
-     
+  const void * key;   /* Copy of, or Pointer to, the Users key */
+  void *data;  /* The users data, this is never copied! */
+
 } SFGHASH_NODE;
 
 /*
@@ -79,10 +79,10 @@ typedef struct _sfghash
 
   unsigned       count;  /* total # nodes in table */
 
-  void         (*userfree)( void * );  
+  void         (*userfree)( void * );
 
-  int            crow;    // findfirst/next row in table
-  SFGHASH_NODE * cnode; // findfirst/next node ptr
+  int            crow;    /* findfirst/next row in table */
+  SFGHASH_NODE * cnode; /* findfirst/next node ptr */
 
   int splay;
 
@@ -94,14 +94,13 @@ typedef struct _sfghash
 */
 SFGHASH * sfghash_new( int nrows, int keysize, int userkeys, void (*userfree)(void*p) );
 void      sfghash_delete( SFGHASH * h );
-int       sfghash_add ( SFGHASH * h, void * key, void * data );
-int       sfghash_remove( SFGHASH * h, void * key);
+int       sfghash_add( SFGHASH * t, const void * const key, void * const data );
+int       sfghash_remove( SFGHASH * h, const void * const key);
 int       sfghash_count( SFGHASH * h);
-void    * sfghash_find( SFGHASH * h, void * key );
+void    * sfghash_find( SFGHASH * h, const void * const key );
 int       sfghash_find2(SFGHASH *, void *, void **);
 SFGHASH_NODE * sfghash_findfirst( SFGHASH * h );
 SFGHASH_NODE * sfghash_findnext ( SFGHASH * h );
-void sfghash_splaymode( SFGHASH * t, int n );
 
 int sfghash_set_keyops( SFGHASH *h ,
                         unsigned (*hash_fcn)( SFHASHFCN * p,
