@@ -52,6 +52,7 @@ typedef struct sf_lnode
 }
 SF_QNODE,SF_SNODE,SF_LNODE;
 
+#define SFLIST_NODE_TO_DATA(node)  (node)->ndata
 
 /*
 *	Integer Stack - uses an array from the subroutines stack
@@ -97,7 +98,7 @@ int       sflist_add_before ( SF_LIST* s, SF_LNODE * lnode, NODE_DATA ndata );
 int       sflist_add_after ( SF_LIST* s, SF_LNODE * lnode, NODE_DATA ndata );
 NODE_DATA sflist_remove_head ( SF_LIST * s);
 NODE_DATA sflist_remove_tail ( SF_LIST * s); 
-void      sflist_remove_node (SF_LIST * s, SF_LNODE * n, void (*free)(void*) );
+void      sflist_remove_node (SF_LIST * s, SF_LNODE * n);
 int       sflist_count ( SF_LIST* s); 
 NODE_DATA sflist_first( SF_LIST * s);
 NODE_DATA sflist_next( SF_LIST * s);
