@@ -41,8 +41,13 @@
 #include "sf_types.h"
 #include "snort_debug.h"
 #include "sfmemcap.h"
-#include "util.h"
 
+#ifndef DYNAMIC_PREPROC_CONTEXT
+#include "util.h"
+#else
+#include "sf_dynamic_preprocessor.h"
+#define SnortAlloc(a) calloc(1,(a))
+#endif   //DYNAMIC_PREPROC_CONTEXT
 /*
 *   Set max # bytes & init other variables.
 */
