@@ -101,7 +101,6 @@
 #include "snort_debug.h"
 #include "sfxhash.h"
 #include "sfprimetable.h"
-#include "util.h"
 
 /**@defgroup sfxhash sourcefire.container.sfxhash
  * Implements SFXHASH as specialized hash container
@@ -174,15 +173,15 @@ int sfxhash_calcrows(int num)
  */
 /*
   Notes:
-  if nrows < 0 don't cal the nearest prime.
+  if nrows < 0 don't cal the nearest powerof2.
   datasize must be the same for all entries, unless datasize is zero.
   maxmem of 0 indicates no memory limits.
 
 */
 SFXHASH * sfxhash_new( int nrows, int keysize, int datasize, unsigned long maxmem,
                        int anr_flag,
-                       int (*anrfree)(void * key, void * data),
-                       int (*usrfree)(void * key, void * data),
+                       SFXHASH_FREE_FCN anrfree,
+                       SFXHASH_FREE_FCN usrfree,
                        int recycle_flag )
 {
     int       i;
@@ -190,7 +189,6 @@ SFXHASH * sfxhash_new( int nrows, int keysize, int datasize, unsigned long maxme
 
     if( nrows > 0 ) /* make sure we have a prime number */
     {
-//        nrows = sf_nearest_prime( nrows );
         /* If nrows is not a power of two, need to find the
          * next highest power of two */
         nrows = sfxhash_nearest_powerof2(nrows);
@@ -201,8 +199,7 @@ SFXHASH * sfxhash_new( int nrows, int keysize, int datasize, unsigned long maxme
     }
 
     /* Allocate the table structure from general memory */
-    //h = (SFXHASH*) calloc( 1, sizeof(SFXHASH) );
-    h = (SFXHASH*)SnortAlloc(sizeof(SFXHASH));
+    h = (SFXHASH*)calloc(1, sizeof(SFXHASH));
     if( !h )
     {
         return 0;
@@ -480,6 +477,11 @@ void sfxhash_glink_node( SFXHASH *t, SFXHASH_NODE * hnode )
 static
 void sfxhash_gunlink_node( SFXHASH *t, SFXHASH_NODE * hnode )
 {
+    if( t->gnode == hnode ) /* if this was the global next node */
+    {
+        t->gnode = hnode->gnext;
+    }
+
     /* Remove the Head Node */
     if( t->ghead == hnode ) /* add the node to head of the the existing list */
     {
@@ -561,6 +563,7 @@ static void movetofront( SFXHASH *t, SFXHASH_NODE * n )
     }
 
     /* Move node in the global hash node list to the front */
+    if (n == t->gnode) t->gnode = n->gnext;
     sfxhash_gmovetofront( t, n );
 }
 
@@ -698,7 +701,7 @@ SFXHASH_NODE * sfxhash_find_node_row( SFXHASH * t, const void * key, int * rinde
  * @retval SFXHASH_INTABLE already in the table, t->cnode points to the node
  * @retval SFXHASH_NOMEM   not enough memory
  */
-int sfxhash_add( SFXHASH * t, void * key, void * data )
+static int sfxhash_add_ex( SFXHASH * t, const void * key, void* data , void **data_ptr)
 {
     int            index;
     SFXHASH_NODE * hnode;
@@ -709,7 +712,8 @@ int sfxhash_add( SFXHASH * t, void * key, void * data )
     if( hnode )
     {
         t->cnode = hnode;
-
+        if (data_ptr)
+            *data_ptr = hnode->data;
         return SFXHASH_INTABLE; /* found it - return it. */
     }
 
@@ -741,6 +745,8 @@ int sfxhash_add( SFXHASH * t, void * key, void * data )
         {
            memcpy(hnode->data,data,t->datasize);
         }
+        if (data_ptr)
+            *data_ptr = hnode->data;
     }
     else
     {
@@ -759,6 +765,10 @@ int sfxhash_add( SFXHASH * t, void * key, void * data )
     return SFXHASH_OK;
 }
 
+int sfxhash_add( SFXHASH * t, void * key, void * data)
+{
+    return sfxhash_add_ex( t, key, data , NULL);
+}
 
 /*!
  * Add a key to the hash table, return the hash node
@@ -814,7 +824,7 @@ SFXHASH_NODE * sfxhash_get_node( SFXHASH * t, const void * key )
     if( t->datasize )
     {
         /* Set up the new data pointer */
-        hnode->data= (char*)hnode + sizeof(SFXHASH_NODE) + t->pad + t->keysize;
+        hnode->data = (char*)hnode + sizeof(SFXHASH_NODE) + t->pad + t->keysize;
     }
     else
     {
@@ -909,6 +919,41 @@ SFXHASH_NODE *sfxhash_gnext( SFXHASH_NODE *n )
     return NULL;
 }
 
+/**
+ * Walk the global list
+ *
+ * @param n current node
+ *
+ * @return the next node in the list or NULL when at the end
+ */
+SFXHASH_NODE *sfxhash_gfindnext( SFXHASH * t )
+{
+    SFXHASH_NODE *n;
+
+    n = t->gnode;
+    if (n) t->gnode = n->gnext;
+    return n;
+}
+
+
+/**
+ * Get the HEAD of the in use list
+ *
+ * @param t table pointer
+ *
+ * @return the head of the list or NULL
+ */
+SFXHASH_NODE *sfxhash_gfindfirst( SFXHASH * t )
+{
+    if(t)
+    {
+        if (t->ghead) t->gnode = t->ghead->gnext;
+        else t->gnode = NULL;
+        return t->ghead;
+    }
+    return NULL;
+}
+
 
 /*!
  * Return the most recently used data from the global list
@@ -1038,7 +1083,7 @@ int sfxhash_free_node( SFXHASH * t, SFXHASH_NODE * hnode)
 
     if( t->usrfree )
     {
-        t->usrfree( hnode->key, hnode->data );
+        t->usrfree( hnode->key, hnode->data);
     }
 
     if( t->recycle_nodes )
@@ -1200,6 +1245,17 @@ int sfxhash_set_keyops( SFXHASH *h ,
     return -1;
 }
 
+int sfxhash_add_return_data_ptr( SFXHASH * t, const void * key, void **data )
+{
+    if( !t->datasize )
+        return SFXHASH_ERR;
+
+    *data = NULL;
+
+    return sfxhash_add_ex(t, key, NULL, data);
+}
+
+
 
 /*
  * -----------------------------------------------------------------------------------------
