@@ -2,7 +2,7 @@
  ** Copyright (C) 2014 Cisco and/or its affiliates. All rights reserved.
  ** Copyright (C) 1998-2013 Sourcefire, Inc.
  **
- ** Writen by Bhagyashree Bantwal <bbantwal@sourcefire.com>
+ ** Writen by Bhagyashree Bantwal <bbantwal@cisco.com>
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License Version 2 as
@@ -42,5 +42,5 @@ typedef struct {
     uint16_t alerts;
 }JSState;
 
-int JSNormalizeDecode(char *, uint16_t , char *, uint16_t destlen, char **, int *, JSState *, int *);
+int JSNormalizeDecode(char *, uint16_t , char *, uint16_t destlen, char **, int *, JSState *, uint8_t *);
 void InitJSNormLookupTable(void);
