@@ -45,6 +45,9 @@ void InitializeProtocolReferenceTable(void);
 void FreeProtoocolReferenceTable(void);
 int16_t AddProtocolReference(const char *protocol);
 int16_t FindProtocolReference(const char *protocol);
+#if defined(FEAT_OPEN_APPID)
+const char * FindProtocolName(int16_t protocol_id);
+#endif /* defined(FEAT_OPEN_APPID) */
 
 int16_t GetProtocolReference(Packet *p);
 
