@@ -159,8 +159,8 @@ HostAttributeEntry *SFAT_LookupHostEntryByDst(Packet *p);
 void SFAT_UpdateApplicationProtocol(sfip_t *ipAddr, uint16_t port, uint16_t protocol, uint16_t id);
 
 /* Returns whether this has been configured */
-int IsAdaptiveConfigured(tSfPolicyId);
-int IsAdaptiveConfiguredForSnortConfig(struct _SnortConfig *, tSfPolicyId);
+int IsAdaptiveConfigured( void );
+int IsAdaptiveConfiguredForSnortConfig(struct _SnortConfig *);
 
 void SFAT_StartReloadThread(void);
 
