@@ -174,7 +174,11 @@ static int get_record(u2iterator *it, u2record *record) {
 
     if ( s_off )
     {
-        fseek(it->file, s_pos+s_off, SEEK_SET);
+        if (fseek(it->file, s_pos+s_off, SEEK_SET)) 
+        {
+            puts("Unable to SEEK on current file .. and this is not being handled yet.");
+            return FAILURE;
+        }
         s_off = 0;
     }
 
@@ -482,6 +486,57 @@ static void event2_dump(u2record *record) {
 
 }
 
+#if defined(FEAT_OPEN_APPID)
+static void event3_dump(u2record *record) 
+{
+    uint8_t *field;
+    int i;
+
+    Serial_Unified2IDSEvent event;
+
+    memcpy(&event, record->data, sizeof(Serial_Unified2IDSEvent));
+
+    /* network to host ordering */
+    /* In the event structure, only the last 40 bits are not 32 bit fields */
+    /* The first 11 fields need to be convertted */
+    field = (uint8_t*)&event;
+    for(i=0; i<11; i++, field+=4) {
+        *(uint32_t*)field = ntohl(*(uint32_t*)field);
+    }
+
+    /* last 3 fields, with the exception of the last most since it's just one byte */
+    *(uint16_t*)field = ntohs(*(uint16_t*)field); /* sport_itype */
+    field += 2;
+    *(uint16_t*)field = ntohs(*(uint16_t*)field); /* dport_icode */
+    field +=6;
+    *(uint32_t*)field = ntohl(*(uint32_t*)field); /* mpls_label */
+    field += 4;
+    /* policy_id and vlanid */
+    for(i=0; i<2; i++, field+=2) {
+        *(uint16_t*)field = ntohs(*(uint16_t*)field);
+    }
+    /* done changing the network ordering */
+
+
+    printf("\n(Event)\n"
+            "\tsensor id: %u\tevent id: %u\tevent second: %u\tevent microsecond: %u\n"
+            "\tsig id: %u\tgen id: %u\trevision: %u\t classification: %u\n"
+            "\tpriority: %u\tip source: %u.%u.%u.%u\tip destination: %u.%u.%u.%u\n"
+            "\tsrc port: %u\tdest port: %u\tprotocol: %u\timpact_flag: %u\tblocked: %u\n"
+            "\tmpls label: %u\tvland id: %u\tpolicy id: %u\tappid: %s\n",
+             event.sensor_id, event.event_id,
+             event.event_second, event.event_microsecond,
+             event.signature_id, event.generator_id,
+             event.signature_revision, event.classification_id,
+             event.priority_id, TO_IP(event.ip_source),
+             TO_IP(event.ip_destination), event.sport_itype,
+             event.dport_icode, event.protocol,
+             event.impact_flag, event.blocked,
+             event.mpls_label, event.vlanId, event.pad2, event.app_name);
+
+}
+
+#endif /* defined(FEAT_OPEN_APPID) */
 static void event2_6_dump(u2record *record) {
     uint8_t *field;
     int i;
@@ -537,6 +592,96 @@ static void event2_6_dump(u2record *record) {
 
 }
 
+#if defined(FEAT_OPEN_APPID)
+static void event3_6_dump(u2record *record) {
+    uint8_t *field;
+    int i;
+    char ip6buf[INET6_ADDRSTRLEN+1];
+    Serial_Unified2IDSEventIPv6 event;
+
+    memcpy(&event, record->data, sizeof(Serial_Unified2IDSEventIPv6));
+
+    /* network to host ordering */
+    /* In the event structure, only the last 40 bits are not 32 bit fields */
+    /* The first fields need to be convertted */
+    field = (uint8_t*)&event;
+    for(i=0; i<9; i++, field+=4) {
+        *(uint32_t*)field = ntohl(*(uint32_t*)field);
+    }
+
+    field = field + 2*sizeof(struct in6_addr);
+
+    /* last 3 fields, with the exception of the last most since it's just one byte */
+    *(uint16_t*)field = ntohs(*(uint16_t*)field); /* sport_itype */
+    field += 2;
+    *(uint16_t*)field = ntohs(*(uint16_t*)field); /* dport_icode */
+    field +=6;
+    *(uint32_t*)field = ntohl(*(uint32_t*)field); /* mpls_label */
+    field += 4;
+    /* policy_id and vlanid */
+    for(i=0; i<2; i++, field+=2) {
+        *(uint16_t*)field = ntohs(*(uint16_t*)field);
+    }
+    /* done changing the network ordering */
+
+    inet_ntop(AF_INET6, &event.ip_source, ip6buf, INET6_ADDRSTRLEN);
+
+    printf("\n(IPv6 Event)\n"
+            "\tsensor id: %u\tevent id: %u\tevent second: %u\tevent microsecond: %u\n"
+            "\tsig id: %u\tgen id: %u\trevision: %u\t classification: %u\n"
+            "\tpriority: %u\tip source: %s\t",
+             event.sensor_id, event.event_id,
+             event.event_second, event.event_microsecond,
+             event.signature_id, event.generator_id,
+             event.signature_revision, event.classification_id,
+             event.priority_id, ip6buf);
+
+
+    inet_ntop(AF_INET6, &event.ip_destination, ip6buf, INET6_ADDRSTRLEN);
+    printf("ip destination: %s\n"
+            "\tsrc port: %u\tdest port: %u\tprotocol: %u\timpact_flag: %u\tblocked: %u\n"
+            "\tmpls label: %u\tvland id: %u\tpolicy id: %u\tappid: %s\n",
+             ip6buf, event.sport_itype,
+             event.dport_icode, event.protocol,
+             event.impact_flag, event.blocked,
+             event.mpls_label, event.vlanId,event.pad2, event.app_name);
+
+}
+
+static void appid_dump(u2record *record) {
+    uint8_t *field = (uint8_t*)record->data;
+    unsigned i;
+    unsigned appCnt;
+    unsigned statTime;
+
+    /* network to host ordering */
+    /* In the event structure, only the last 40 bits are not 32 bit fields */
+    /* The first fields need to be convertted */
+    statTime = ntohl(*(uint32_t*)field);
+    field += 4;
+    appCnt = ntohl(*(uint32_t*)field); 
+    field += 4;
+    
+    printf("\n(AppId Stats)\n"
+            "    event second: %u\tRecordCount: %u\n",
+             statTime, appCnt);
+    for(i=0; i<appCnt; i++) 
+    {
+        char appName[MAX_EVENT_APPNAME_LEN];
+        memcpy(appName, field, sizeof(appName));
+        field += MAX_EVENT_APPNAME_LEN;
+
+        int txBytes = ntohl(*(uint32_t*)field);
+        field += 4;
+        int rxBytes = ntohl(*(uint32_t*)field);
+        field += 4;
+
+        printf("    -----------\n\tApp:%s\n\tbytes_out: %u\n\tbytes_in: %u\n",
+            appName, txBytes, rxBytes);
+     }
+}
+
+#endif /* defined(FEAT_OPEN_APPID) */
 static inline void print_uuid (const char* label, uint8_t* data)
 {
 #ifdef HAVE_LIBUUID
@@ -639,6 +784,12 @@ static int u2dump(char *file) {
         else if(record.type == UNIFIED2_IDS_EVENT_IPV6) event6_dump(&record);
         else if(record.type == UNIFIED2_IDS_EVENT_IPV6_VLAN) event2_6_dump(&record);
         else if(record.type == UNIFIED2_EXTRA_DATA) extradata_dump(&record);
+#if defined(FEAT_OPEN_APPID)
+
+        else if(record.type == UNIFIED2_IDS_EVENT_APPID) event3_dump(&record);
+        else if(record.type == UNIFIED2_IDS_EVENT_APPID_IPV6) event3_6_dump(&record);
+        else if(record.type == UNIFIED2_IDS_EVENT_APPSTAT) appid_dump(&record);
+#endif /* defined(FEAT_OPEN_APPID) */
     }
 
     free_iterator(it);
